@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: GPL-2.0
-/* Copyright (C) 2009-2020  B.A.T.M.A.N. contributors:
+/* Copyright (C) B.A.T.M.A.N. contributors:
  *
  * Antonio Quartulli <a@unstable.cc>
  *
@@ -36,7 +36,7 @@ static int get_attrs_ap_isolation(struct nl_msg *msg, void *arg)
 
 static int get_ap_isolation(struct state *state)
 {
-	enum batadv_nl_commands nl_cmd = BATADV_CMD_SET_MESH;
+	enum batadv_nl_commands nl_cmd = BATADV_CMD_GET_MESH;
 
 	if (state->selector == SP_VLAN)
 		nl_cmd = BATADV_CMD_GET_VLAN;
@@ -70,7 +70,6 @@ static int set_ap_isolation(struct state *state)
 }
 
 static struct settings_data batctl_settings_ap_isolation = {
-	.sysfs_name = "ap_isolation",
 	.data = &ap_isolation,
 	.parse = parse_simple_boolean,
 	.netlink_get = get_ap_isolation,
